export type MobileDeviceType = 'ANDROID' | 'IOS' | 'ETC'

const checkSupportIntersectionObserver = () => ('IntersectionObserver' in window)
    || ('IntersectionObserverEntry' in window)
    || ('intersectionRatio' in ((window as any)?.IntersectionObserverEntry?.prototype || {}))

const checkMobileDevice = (): MobileDeviceType => {
  const userAgent = navigator.userAgent.toLowerCase();

  if (userAgent.indexOf('android') > -1)
    return 'ANDROID'
  else if (userAgent.indexOf('iphone') > -1
      || userAgent.indexOf('ipad') > -1
      || userAgent.indexOf('ipod') > -1)
    return 'IOS'
  else
    return 'ETC'
}

const checkSupportWebp = (): boolean => {
  // https://stackoverflow.com/questions/5573096/detecting-webp-support
  const elem = document.createElement('canvas')
  return elem.getContext && elem.getContext('2d')
      // was able or not to get WebP representation
      ? elem.toDataURL('image/webp').indexOf('data:image/webp') === 0
      // very old browser like IE 8, canvas not supported
      : false
}

export const mobileDeviceType = checkMobileDevice()
export const supportWebp = checkSupportWebp()
export const supportIntersectionObserver = checkSupportIntersectionObserver()
